@@ -4,6 +4,7 @@ from task import task_add
 from task import task_list
 from task import task_rm
 from task import task_done
+from task import task_describe
 
 __version__ = "0.1.0"
 
@@ -24,6 +25,7 @@ main.add_command(task_add.main)
 main.add_command(task_list.main)
 main.add_command(task_rm.main)
 main.add_command(task_done.main)
+main.add_command(task_describe.main)
 
 
 if __name__ == '__main__':
