@@ -1,5 +1,4 @@
 import click
-from datetime import datetime
 from click_default_group import DefaultGroup
 
 from task import utils
@@ -15,11 +14,6 @@ def main():
     """Add task"""
 
 
-def format_current_time() -> str:
-    date = str(datetime.now())
-    return date.split('.')[0]
-
-
 @main.command()
 @click.argument('task', type=click.STRING)
 @click.option('-p', '--project', help="specyfiy project")
@@ -29,13 +23,12 @@ def new_task(task: str, project: str = None, urgency: int = 0, due: str = None):
     """Add task to database."""
     if utils.does_db_exist()[0] is False:
         utils.create_db()
-    else:
-        print("don't create db")
 
     task_data = dict()
     task_data['task'] = task
     task_data['project'] = project
     task_data['urgency'] = urgency
-    task_data['due'] = due
-    task_data['datetime'] = format_current_time()
+    task_data['due'] = utils.parse_due(due)
+    task_data['created_at'] = utils.format_current_time()
+    task_data['updated_at'] = utils.format_current_time()
     utils.insert_to_db(task_data)
