@@ -24,5 +24,5 @@ def remove_task(task_id: int = 0) -> int:
 
     # if task is 0 make sure we remove latest task entry
     utils.remove_entry(task_id)
-    print("Done")
+    print(f"Removed task {task_id}")
     return task_id
